1
0
mirror of https://git.FreeBSD.org/ports.git synced 2024-11-22 00:35:15 +00:00

Fix mkntfs

Replace Vista's $UpCase file by a Windows XP one
Pass maintainership to submitter
Remove md5 sum while I'm here

PR:		ports/144852
Submitted by:	Samuel Martin Moro <faust64 at gmail.com>
This commit is contained in:
Max Brazhnikov 2011-03-17 16:21:09 +00:00
parent 950ff76354
commit 6e84b9879a
Notes: svn2git 2021-03-31 03:12:20 +00:00
svn path=/head/; revision=271142
5 changed files with 294 additions and 27 deletions

View File

@ -7,11 +7,11 @@
PORTNAME= ntfsprogs
PORTVERSION= 2.0.0
PORTREVISION= 1
PORTREVISION= 2
CATEGORIES= sysutils
MASTER_SITES= SF/linux-ntfs/NTFS%20Tools%20and%20Library/${PORTVERSION}
MAINTAINER= ports@FreeBSD.org
MAINTAINER= faust64@gmail.com
COMMENT= Utilities and library to manipulate NTFS partitions
BUILD_DEPENDS= fusefs-libs>2.5:${PORTSDIR}/sysutils/fusefs-libs

View File

@ -1,3 +1,2 @@
MD5 (ntfsprogs-2.0.0.tar.bz2) = 2b39dece8897bc748f4ab4c40ec7699e
SHA256 (ntfsprogs-2.0.0.tar.bz2) = ad36e19706c7303b10aa0a9bf2c2dd0309b91cd0171f1c9eb361d94a85017432
SIZE (ntfsprogs-2.0.0.tar.bz2) = 678114

View File

@ -1,6 +1,6 @@
--- ./libntfs/device.c.orig Tue Jan 9 18:22:57 2007
+++ ./libntfs/device.c Mon Apr 30 13:40:54 2007
@@ -63,6 +63,9 @@
--- libntfs/unistr.c.orig 2007-09-26 20:28:34.000000000 +0200
+++ libntfs/unistr.c 2010-03-24 16:01:11.000000000 +0100
@@ -640,86 +640,64 @@
* ntfs_upcase_table_build() builds the default upcase table for NTFS and
* stores it in the caller supplied buffer @uc of size @uc_len.
*
- * The generated $UpCase table is the one used by Windows Vista.
+ * The generated $UpCase table is the one used by Windows XP.
*
* Note, @uc_len must be at least 128kiB in size or bad things will happen!
*/
void ntfs_upcase_table_build(ntfschar *uc, u32 uc_len)
{
- /*
- * "Start" is inclusive and "End" is exclusive, every value has the
- * value of "Add" added to it.
- */
- static int add[][3] = { /* Start, End, Add */
- {0x0061, 0x007b, -32}, {0x00e0, 0x00f7, -32}, {0x00f8, 0x00ff, -32},
- {0x0256, 0x0258, -205}, {0x028a, 0x028c, -217}, {0x037b, 0x037e, 130},
- {0x03ac, 0x03ad, -38}, {0x03ad, 0x03b0, -37}, {0x03b1, 0x03c2, -32},
- {0x03c2, 0x03c3, -31}, {0x03c3, 0x03cc, -32}, {0x03cc, 0x03cd, -64},
- {0x03cd, 0x03cf, -63}, {0x0430, 0x0450, -32}, {0x0450, 0x0460, -80},
- {0x0561, 0x0587, -48}, {0x1f00, 0x1f08, 8}, {0x1f10, 0x1f16, 8},
- {0x1f20, 0x1f28, 8}, {0x1f30, 0x1f38, 8}, {0x1f40, 0x1f46, 8},
- {0x1f51, 0x1f52, 8}, {0x1f53, 0x1f54, 8}, {0x1f55, 0x1f56, 8},
- {0x1f57, 0x1f58, 8}, {0x1f60, 0x1f68, 8}, {0x1f70, 0x1f72, 74},
- {0x1f72, 0x1f76, 86}, {0x1f76, 0x1f78, 100}, {0x1f78, 0x1f7a, 128},
- {0x1f7a, 0x1f7c, 112}, {0x1f7c, 0x1f7e, 126}, {0x1f80, 0x1f88, 8},
- {0x1f90, 0x1f98, 8}, {0x1fa0, 0x1fa8, 8}, {0x1fb0, 0x1fb2, 8},
- {0x1fb3, 0x1fb4, 9}, {0x1fcc, 0x1fcd, -9}, {0x1fd0, 0x1fd2, 8},
- {0x1fe0, 0x1fe2, 8}, {0x1fe5, 0x1fe6, 7}, {0x1ffc, 0x1ffd, -9},
- {0x2170, 0x2180, -16}, {0x24d0, 0x24ea, -26}, {0x2c30, 0x2c5f, -48},
- {0x2d00, 0x2d26, -7264}, {0xff41, 0xff5b, -32}, {0}
+ static int uc_run_table[][3] = { /* Start, End, Add */
+ {0x0061, 0x007B, -32}, {0x0451, 0x045D, -80}, {0x1F70, 0x1F72, 74},
+ {0x00E0, 0x00F7, -32}, {0x045E, 0x0460, -80}, {0x1F72, 0x1F76, 86},
+ {0x00F8, 0x00FF, -32}, {0x0561, 0x0587, -48}, {0x1F76, 0x1F78, 100},
+ {0x0256, 0x0258, -205}, {0x1F00, 0x1F08, 8}, {0x1F78, 0x1F7A, 128},
+ {0x028A, 0x028C, -217}, {0x1F10, 0x1F16, 8}, {0x1F7A, 0x1F7C, 112},
+ {0x03AC, 0x03AD, -38}, {0x1F20, 0x1F28, 8}, {0x1F7C, 0x1F7E, 126},
+ {0x03AD, 0x03B0, -37}, {0x1F30, 0x1F38, 8}, {0x1FB0, 0x1FB2, 8},
+ {0x03B1, 0x03C2, -32}, {0x1F40, 0x1F46, 8}, {0x1FD0, 0x1FD2, 8},
+ {0x03C2, 0x03C3, -31}, {0x1F51, 0x1F52, 8}, {0x1FE0, 0x1FE2, 8},
+ {0x03C3, 0x03CC, -32}, {0x1F53, 0x1F54, 8}, {0x1FE5, 0x1FE6, 7},
+ {0x03CC, 0x03CD, -64}, {0x1F55, 0x1F56, 8}, {0x2170, 0x2180, -16},
+ {0x03CD, 0x03CF, -63}, {0x1F57, 0x1F58, 8}, {0x24D0, 0x24EA, -26},
+ {0x0430, 0x0450, -32}, {0x1F60, 0x1F68, 8}, {0xFF41, 0xFF5B, -32},
+ {0}
};
- /*
- * "Start" is exclusive and "End" is inclusive, every second value is
- * decremented by one.
- */
- static int skip_dec[][2] = { /* Start, End */
- {0x0100, 0x012f}, {0x0132, 0x0137}, {0x0139, 0x0149}, {0x014a, 0x0178},
- {0x0179, 0x017e}, {0x01a0, 0x01a6}, {0x01b3, 0x01b7}, {0x01cd, 0x01dd},
- {0x01de, 0x01ef}, {0x01f4, 0x01f5}, {0x01f8, 0x01f9}, {0x01fa, 0x0220},
- {0x0222, 0x0234}, {0x023b, 0x023c}, {0x0241, 0x0242}, {0x0246, 0x024f},
- {0x03d8, 0x03ef}, {0x03f7, 0x03f8}, {0x03fa, 0x03fb}, {0x0460, 0x0481},
- {0x048a, 0x04bf}, {0x04c1, 0x04c4}, {0x04c5, 0x04c8}, {0x04c9, 0x04ce},
- {0x04ec, 0x04ed}, {0x04d0, 0x04eb}, {0x04ee, 0x04f5}, {0x04f6, 0x0513},
- {0x1e00, 0x1e95}, {0x1ea0, 0x1ef9}, {0x2183, 0x2184}, {0x2c60, 0x2c61},
- {0x2c67, 0x2c6c}, {0x2c75, 0x2c76}, {0x2c80, 0x2ce3}, {0}
+ static int uc_dup_table[][2] = { /* Start, End */
+ {0x0100, 0x012F}, {0x01A0, 0x01A6}, {0x03E2, 0x03EF}, {0x04CB, 0x04CC},
+ {0x0132, 0x0137}, {0x01B3, 0x01B7}, {0x0460, 0x0481}, {0x04D0, 0x04EB},
+ {0x0139, 0x0149}, {0x01CD, 0x01DD}, {0x0490, 0x04BF}, {0x04EE, 0x04F5},
+ {0x014A, 0x0178}, {0x01DE, 0x01EF}, {0x04BF, 0x04BF}, {0x04F8, 0x04F9},
+ {0x0179, 0x017E}, {0x01F4, 0x01F5}, {0x04C1, 0x04C4}, {0x1E00, 0x1E95},
+ {0x018B, 0x018B}, {0x01FA, 0x0218}, {0x04C7, 0x04C8}, {0x1EA0, 0x1EF9},
+ {0}
};
- /*
- * Set the Unicode character at offset "Offset" to "Value". Note,
- * "Value" is host endian.
- */
- static int set[][2] = { /* Offset, Value */
- {0x00ff, 0x0178}, {0x0180, 0x0243}, {0x0183, 0x0182}, {0x0185, 0x0184},
- {0x0188, 0x0187}, {0x018c, 0x018b}, {0x0192, 0x0191}, {0x0195, 0x01f6},
- {0x0199, 0x0198}, {0x019a, 0x023d}, {0x019e, 0x0220}, {0x01a8, 0x01a7},
- {0x01ad, 0x01ac}, {0x01b0, 0x01af}, {0x01b9, 0x01b8}, {0x01bd, 0x01bc},
- {0x01bf, 0x01f7}, {0x01c6, 0x01c4}, {0x01c9, 0x01c7}, {0x01cc, 0x01ca},
- {0x01dd, 0x018e}, {0x01f3, 0x01f1}, {0x023a, 0x2c65}, {0x023e, 0x2c66},
- {0x0253, 0x0181}, {0x0254, 0x0186}, {0x0259, 0x018f}, {0x025b, 0x0190},
- {0x0260, 0x0193}, {0x0263, 0x0194}, {0x0268, 0x0197}, {0x0269, 0x0196},
- {0x026b, 0x2c62}, {0x026f, 0x019c}, {0x0272, 0x019d}, {0x0275, 0x019f},
- {0x027d, 0x2c64}, {0x0280, 0x01a6}, {0x0283, 0x01a9}, {0x0288, 0x01ae},
- {0x0289, 0x0244}, {0x028c, 0x0245}, {0x0292, 0x01b7}, {0x03f2, 0x03f9},
- {0x04cf, 0x04c0}, {0x1d7d, 0x2c63}, {0x214e, 0x2132}, {0}
+ static int uc_byte_table[][2] = { /* Offset, Value */
+ {0x00FF, 0x0178}, {0x01AD, 0x01AC}, {0x01F3, 0x01F1}, {0x0269, 0x0196},
+ {0x0183, 0x0182}, {0x01B0, 0x01AF}, {0x0253, 0x0181}, {0x026F, 0x019C},
+ {0x0185, 0x0184}, {0x01B9, 0x01B8}, {0x0254, 0x0186}, {0x0272, 0x019D},
+ {0x0188, 0x0187}, {0x01BD, 0x01BC}, {0x0259, 0x018F}, {0x0275, 0x019F},
+ {0x018C, 0x018B}, {0x01C6, 0x01C4}, {0x025B, 0x0190}, {0x0283, 0x01A9},
+ {0x0192, 0x0191}, {0x01C9, 0x01C7}, {0x0260, 0x0193}, {0x0288, 0x01AE},
+ {0x0199, 0x0198}, {0x01CC, 0x01CA}, {0x0263, 0x0194}, {0x0292, 0x01B7},
+ {0x01A8, 0x01A7}, {0x01DD, 0x018E}, {0x0268, 0x0197},
+ {0}
};
- unsigned i, r;
+ int i, r;
- memset(uc, 0, uc_len);
- uc_len /= 2;
- /* Start with a one-to-one mapping, i.e. no upcasing happens at all. */
- for (i = 0; i < uc_len; i++)
- uc[i] = cpu_to_le16(i);
- /* Adjust specified runs by the specified amount. */
- for (r = 0; add[r][0]; r++)
- for (i = add[r][0]; i < add[r][1]; i++)
- uc[i] = cpu_to_le16(le16_to_cpu(uc[i]) + add[r][2]);
- /* Decrement every second value in specified runs. */
- for (r = 0; skip_dec[r][0]; r++)
- for (i = skip_dec[r][0]; i < skip_dec[r][1];
- i += 2)
- uc[i + 1] = cpu_to_le16(le16_to_cpu(uc[i + 1]) - 1);
- /* Set specified characters to specified values. */
- for (r = 0; set[r][0]; r++)
- uc[set[r][0]] = cpu_to_le16(set[r][1]);
+ memset((char*)uc, 0, uc_len);
+ uc_len >>= 1;
+ if (uc_len > 65536)
+ uc_len = 65536;
+ for (i = 0; (u32)i < uc_len; i++)
+ uc[i] = i;
+ for (r = 0; uc_run_table[r][0]; r++)
+ for (i = uc_run_table[r][0]; i < uc_run_table[r][1]; i++)
+ uc[i] += uc_run_table[r][2];
+ for (r = 0; uc_dup_table[r][0]; r++)
+ for (i = uc_dup_table[r][0]; i < uc_dup_table[r][1]; i += 2)
+ uc[i + 1]--;
+ for (r = 0; uc_byte_table[r][0]; r++)
+ uc[uc_byte_table[r][0]] = uc_byte_table[r][1];
}
/**

View File

@ -0,0 +1,31 @@
--- ntfsprogs/mkntfs.c 2007-09-19 18:51:09.000000000 +0200
+++ ntfsprogs/mkntfs.c 2010-03-16 17:26:42.000000000 +0100
@@ -552,12 +552,16 @@
total = 0LL;
retry = 0;
do {
- bytes_written = dev->d_ops->write(dev, b, count);
+ bytes_written = (long long)dev->d_ops->write(dev, b, count);
if (bytes_written == -1LL) {
retry = errno;
ntfs_log_perror("Error writing to %s", dev->d_name);
errno = retry;
return bytes_written;
+ } else if (bytes_written < 0) {
+ errno = EINVAL;
+ ntfs_log_error("Failed to write to device %s.\n", dev->d_name);
+ return -1;
} else if (!bytes_written) {
retry++;
} else {
@@ -3072,8 +3076,8 @@
goto done;
}
- if (!S_ISBLK(sbuf.st_mode)) {
- ntfs_log_error("%s is not a block device.\n", vol->dev->d_name);
+ if (!S_ISCHR(sbuf.st_mode)) {
+ ntfs_log_error("%s is not a character device.\n", vol->dev->d_name);
if (!opts.force) {
ntfs_log_error("Refusing to make a filesystem here!\n");
goto done;
--- ./libntfs/device.c.orig 2007-09-26 22:28:34.000000000 +0400
+++ ./libntfs/device.c 2011-03-15 23:07:06.183948162 +0300
@@ -62,6 +62,9 @@
#ifdef HAVE_LINUX_HDREG_H
#include <linux/hdreg.h>
#endif
@ -10,7 +10,7 @@
#include "types.h"
#include "mst.h"
@@ -533,6 +536,17 @@
@@ -599,6 +602,17 @@
}
}
#endif
@ -28,29 +28,128 @@
/*
* We couldn't figure it out by using a specialized ioctl,
* so do binary search to find the size of the device.
@@ -681,7 +695,24 @@
return sect_size;
@@ -627,8 +641,8 @@
*
* The following error codes are defined:
* EINVAL Input parameter error
* EOPNOTSUPP System does not support HDIO_GETGEO ioctl
* ENOTTY @dev is a file or a device not supporting HDIO_GETGEO
*/
s64 ntfs_device_partition_start_sector_get(struct ntfs_device *dev)
{
@@ -636,13 +650,13 @@
errno = EINVAL;
return -1;
}
-#ifdef HDIO_GETGEO
- { struct hd_geometry geo;
+#ifdef DIOCGFWSECTORS
+ { u_int start_sector = 0;
- if (!dev->d_ops->ioctl(dev, HDIO_GETGEO, &geo)) {
- ntfs_log_debug("HDIO_GETGEO start_sect = %lu (0x%lx)\n",
- geo.start, geo.start);
- return geo.start;
+ if (!dev->d_ops->ioctl(dev, DIOCGFWSECTORS, &start_sector)) {
+ ntfs_log_debug("DIOCGFWSECTORS start_sect = %lu (0x%lx)\n",
+ start_sector, start_sector);
+ return start_sector;
}
}
-#else
+#elif defined(DIOCGSECTORSIZE)
+ /*
+ * XXX On FreeBSD (where we have DIOCGSECTORSIZE) the low-level I/O
+ * system already knows the sector size, and doing an ioctl is needless.
+ * However, I don't know how to extract that information cleanly,
+ * without letting a bunch of platform specific #ifdef-s to sneak in.
+ * So now I rather just re-do the ioctl...
+ */
+ {
#else
@@ -660,8 +674,8 @@
*
* The following error codes are defined:
* EINVAL Input parameter error
* EOPNOTSUPP System does not support HDIO_GETGEO ioctl
* ENOTTY @dev is a file or a device not supporting HDIO_GETGEO
*/
int ntfs_device_heads_get(struct ntfs_device *dev)
{
@@ -669,14 +683,13 @@
errno = EINVAL;
return -1;
}
-#ifdef HDIO_GETGEO
- { struct hd_geometry geo;
+#ifdef DIOCGFWHEADS
+ { u_int heads;
- if (!dev->d_ops->ioctl(dev, HDIO_GETGEO, &geo)) {
- ntfs_log_debug("HDIO_GETGEO heads = %u (0x%x)\n",
- (unsigned)geo.heads,
- (unsigned)geo.heads);
- return geo.heads;
+ if (!dev->d_ops->ioctl(dev, DIOCGFWHEADS, &heads)) {
+ ntfs_log_debug("DIOCGFWHEADS heads = %u (0x%x)\n",
+ heads, heads);
+ return heads;
}
}
#else
@@ -694,8 +707,8 @@
*
* The following error codes are defined:
* EINVAL Input parameter error
* EOPNOTSUPP System does not support HDIO_GETGEO ioctl
* ENOTTY @dev is a file or a device not supporting HDIO_GETGEO
*/
int ntfs_device_sectors_per_track_get(struct ntfs_device *dev)
{
@@ -703,14 +716,13 @@
errno = EINVAL;
return -1;
}
-#ifdef HDIO_GETGEO
- { struct hd_geometry geo;
+#ifdef DIOCGFWSECTORS
+ { u_int sptrack;
- if (!dev->d_ops->ioctl(dev, HDIO_GETGEO, &geo)) {
- ntfs_log_debug("HDIO_GETGEO sectors_per_track = %u (0x%x)\n",
- (unsigned)geo.sectors,
- (unsigned)geo.sectors);
- return geo.sectors;
+ if (!dev->d_ops->ioctl(dev, DIOCGFWSECTORS, &sptrack)) {
+ ntfs_log_debug("DIOCGFWSECTORS sectors_per_track = %u (0x%x)\n",
+ sptrack, sptrack);
+ return sptrack;
}
}
#else
@@ -728,8 +740,8 @@
*
* The following error codes are defined:
* EINVAL Input parameter error
* EOPNOTSUPP System does not support BLKSSZGET ioctl
* ENOTTY @dev is a file or a device not supporting BLKSSZGET
*/
int ntfs_device_sector_size_get(struct ntfs_device *dev)
{
@@ -737,13 +749,13 @@
errno = EINVAL;
return -1;
}
-#ifdef BLKSSZGET
+#ifdef DIOCGSECTORSIZE
{
- int sect_size = 0;
+ size_t sect_size = 0;
+
- if (!dev->d_ops->ioctl(dev, BLKSSZGET, &sect_size)) {
- ntfs_log_debug("BLKSSZGET sector size = %d bytes\n",
- sect_size);
+ if (!dev->d_ops->ioctl(dev, DIOCGSECTORSIZE, &sect_size)) {
+ ntfs_log_debug("DIOCGSECTORSIZE sector size = %d bytes\n",
+ (int)sect_size);
+ return sect_size;
+ }
+ }
+#else
errno = EOPNOTSUPP;
#endif
return -1;
return sect_size;
}
}

View File

@ -0,0 +1,138 @@
@@ -627,8 +641,8 @@
* The following error codes are defined:
* EINVAL Input parameter error
- * EOPNOTSUPP System does not support HDIO_GETGEO ioctl
- * ENOTTY @dev is a file or a device not supporting HDIO_GETGEO
+ * EOPNOTSUPP System does not support DIOCGFWSECTORS ioctl
+ * ENOTTY @dev is a file or a device not supporting DIOCGFWSECTORS
*/
s64 ntfs_device_partition_start_sector_get(struct ntfs_device *dev)
@@ -660,8 +674,8 @@
* The following error codes are defined:
* EINVAL Input parameter error
- * EOPNOTSUPP System does not support HDIO_GETGEO ioctl
- * ENOTTY @dev is a file or a device not supporting HDIO_GETGEO
+ * EOPNOTSUPP System does not support DIOCGFWHEADS ioctl
+ * ENOTTY @dev is a file or a device not supporting DIOCGFWHEADS
*/
int ntfs_device_heads_get(struct ntfs_device *dev)
@@ -694,8 +707,8 @@
* The following error codes are defined:
* EINVAL Input parameter error
- * EOPNOTSUPP System does not support HDIO_GETGEO ioctl
- * ENOTTY @dev is a file or a device not supporting HDIO_GETGEO
+ * EOPNOTSUPP System does not support DIOCGFWSECTORS ioctl
+ * ENOTTY @dev is a file or a device not supporting DIOCGFWSECTORS
*/
int ntfs_device_sectors_per_track_get(struct ntfs_device *dev)
@@ -728,8 +740,8 @@
* The following error codes are defined:
* EINVAL Input parameter error
- * EOPNOTSUPP System does not support BLKSSZGET ioctl
- * ENOTTY @dev is a file or a device not supporting BLKSSZGET
+ * EOPNOTSUPP System does not support DIOCGSECTORSIZE ioctl
+ * ENOTTY @dev is a file or a device not supporting DIOCGSECTORSIZE
*/
int ntfs_device_sector_size_get(struct ntfs_device *dev)